# fps-localspace

[![PyPI - Version](https://img.shields.io/pypi/v/fps-localspace.svg)](https://pypi.org/project/fps-localspace)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/fps-localspace.svg)](https://pypi.org/project/fps-localspace)

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install fps-localspace
```

## License

`fps-localspace` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
